Computes the most frequent nominal class per cell. It never calculates a numeric median of class IDs.
Usage
modal_mesohabitat(x, ties = c("NA", "lowest_class"), na.rm = TRUE)Computes the most frequent nominal class per cell. It never calculates a numeric median of class IDs.
modal_mesohabitat(x, ties = c("NA", "lowest_class"), na.rm = TRUE)